import{O as r}from"./workspaceStore.66fb9534.js";import{d as l,X as i,o as u,Y as c,b as a,w as o,u as n,aG as d,dd as f,dc as _}from"./index.c4f9f025.js";import"./url.b319ee4d.js";import"./colorHelpers.4725e4d8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="869637ad-e4fa-457a-945c-c394731d0381",e._sentryDebugIdIdentifier="sentry-dbid-869637ad-e4fa-457a-945c-c394731d0381")}catch{}})();const b=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(_),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLogoutCallback.044942a0.js.map
