import{d as l,eh as c,f as r,o as t,Y as a,S as d,e9 as _,a0 as p}from"./index.c4f9f025.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="dd7233f5-b310-4405-872b-ee3e1b766ac1",e._sentryDebugIdIdentifier="sentry-dbid-dd7233f5-b310-4405-872b-ee3e1b766ac1")}catch{}})();const u={class:"logo"},g=["src","alt"],f={key:1},m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;c(o=>({"9303a762":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),i=r(()=>`${s.brandName} Logo`);return(o,b)=>(t(),a("div",u,[o.imageUrl?(t(),a("img",{key:0,class:"logo-img",src:o.imageUrl,alt:i.value},null,8,g)):d("",!0),o.hideText?d("",!0):(t(),a("span",f,_(o.brandName),1))]))}});const h=p(m,[["__scopeId","data-v-f2a3ae27"]]);export{h as L};
//# sourceMappingURL=Logo.88222daa.js.map
