import{cM as n}from"./index.c4f9f025.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="312f63dd-64e9-41d0-9b31-32a2ca4be781",e._sentryDebugIdIdentifier="sentry-dbid-312f63dd-64e9-41d0-9b31-32a2ca4be781")}catch{}})();const t=(e,d,r)=>{n.error({message:e,description:d,onClick:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.ebc30b56.js.map
