import{C as r}from"./ContentLayout.878e9d53.js";import{_ as i}from"./Logs.vue_vue_type_script_setup_true_lang.0586507b.js";import{L as n}from"./ExecutionStatusIcon.vue_vue_type_script_setup_true_lang.31820e21.js";import{d as s,o as a,c as p,w as f,b as m,u as c}from"./index.c4f9f025.js";import"./gateway.408bdde1.js";import"./popupNotifcation.ebc30b56.js";import"./build.4c8cfde3.js";import"./string.45b9e9dc.js";import"./tables.95f3c281.js";import"./record.8b302d80.js";import"./polling.19d6afa8.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.54c4b6d6.js";import"./datetime.b3e67b74.js";import"./ant-design.b662a793.js";import"./index.c251cf6d.js";import"./index.6797054a.js";import"./dayjs.a30dbbb3.js";import"./CollapsePanel.3b1ab867.js";import"./LoadingOutlined.7c61f089.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="4d9f5862-1ae8-431d-b0ba-cc5afe226f2b",o._sentryDebugIdIdentifier="sentry-dbid-4d9f5862-1ae8-431d-b0ba-cc5afe226f2b")}catch{}})();const V=s({__name:"Logs",setup(o){const e=new n;return(t,d)=>(a(),p(r,null,{default:f(()=>[m(i,{"execution-repository":c(e),"build-repository":null,"show-all-filters":!1},null,8,["execution-repository"])]),_:1}))}});export{V as default};
//# sourceMappingURL=Logs.8b702617.js.map
