import"./App.vue_vue_type_style_index_0_lang.4723527c.js";import{_ as a}from"./App.vue_vue_type_style_index_0_lang.4723527c.js";import"./workspaceStore.66fb9534.js";import"./index.c4f9f025.js";import"./url.b319ee4d.js";import"./colorHelpers.4725e4d8.js";import"./PlayerConfigProvider.19373623.js";import"./index.44d5a9ff.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f662bc48-44b6-4280-9c57-29f6dbdb0ce9",e._sentryDebugIdIdentifier="sentry-dbid-f662bc48-44b6-4280-9c57-29f6dbdb0ce9")}catch{}})();export{a as default};
//# sourceMappingURL=App.e4ca7e5b.js.map
