import{d as u,o as d,c as l,w as t,b as s,u as a,dh as o,d5 as _,aG as r,S as p,dc as c,e9 as i,ed as y,a0 as b}from"./index.c4f9f025.js";import{A as g}from"./Avatar.9bb6d17c.js";import{C}from"./Card.b2dea59d.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="072ede1f-fdcc-47c9-b580-8c08ab7f31f7",n._sentryDebugIdIdentifier="sentry-dbid-072ede1f-fdcc-47c9-b580-8c08ab7f31f7")}catch{}})();const m=u({__name:"ConnectorCard",props:{title:{},logoUrl:{},description:{},unavailable:{type:Boolean}},setup(n){return(e,f)=>(d(),l(a(C),{class:y({"connector-card":!0,unavailable:e.unavailable})},{default:t(()=>[s(a(o),{style:{width:"100%"},vertical:"",gap:12},{default:t(()=>[s(a(o),{justify:"space-between"},{default:t(()=>[s(a(g),{src:e.logoUrl,shape:"square",size:"large"},null,8,["src"]),e.unavailable?(d(),l(a(_),{key:0,style:{height:"fit-content"}},{default:t(()=>[r("Talk to us")]),_:1})):p("",!0)]),_:1}),s(a(o),{vertical:""},{default:t(()=>[s(a(c),{strong:""},{default:t(()=>[r(i(e.title),1)]),_:1}),s(a(c),{type:"secondary"},{default:t(()=>[r(i(e.description),1)]),_:1})]),_:1})]),_:1})]),_:1},8,["class"]))}});const I=b(m,[["__scopeId","data-v-e3719550"]]);export{I as C};
//# sourceMappingURL=ConnectorCard.5ea119a1.js.map
