import{B as d}from"./BookOutlined.ec23cf35.js";import{d as f,o as a,c,w as o,b as l,u as n,$ as u,Y as i,aG as p,aS as b,bT as y}from"./index.c4f9f025.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="60138c74-f0bd-4ad7-9596-c1e05908dff6",t._sentryDebugIdIdentifier="sentry-dbid-60138c74-f0bd-4ad7-9596-c1e05908dff6")}catch{}})();const g=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),c(n(y),{class:"docs-button",href:`https://abstra.io/docs/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.00c3f4e2.js.map
