import{d as i,o as p,c as n,w as m,b as a,u as r}from"./index.c4f9f025.js";import"./linters.cd09d15a.js";import{W as s}from"./workspaces.8642e7e0.js";import{C as f}from"./ContentLayout.878e9d53.js";import{_ as d,E as c}from"./View.vue_vue_type_script_setup_true_lang.17cbdacc.js";import"./asyncComputed.bfad5b5f.js";import"./workspaceStore.66fb9534.js";import"./url.b319ee4d.js";import"./colorHelpers.4725e4d8.js";import"./record.8b302d80.js";import"./gateway.408bdde1.js";import"./popupNotifcation.ebc30b56.js";import"./fetch.02ea8ffd.js";import"./SaveButton.e6b204c5.js";import"./UnsavedChangesHandler.b2721048.js";import"./ExclamationCircleOutlined.d86a7477.js";import"./CrudView.326cc18b.js";import"./router.a2550079.js";import"./Badge.f662d019.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.00c3f4e2.js";import"./BookOutlined.ec23cf35.js";import"./PhDotsThreeVertical.vue.d3a732a1.js";import"./index.6797054a.js";import"./index.c251cf6d.js";import"./polling.19d6afa8.js";import"./PhPencil.vue.e6ad1f42.js";import"./index.8a59a397.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e9c57e5f-7ee1-4989-a5a7-3e96611f50be",e._sentryDebugIdIdentifier="sentry-dbid-e9c57e5f-7ee1-4989-a5a7-3e96611f50be")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(e){const o=new c;return(t,u)=>(p(),n(f,null,{default:m(()=>[a(d,{"env-var-repository":r(o),mode:"editor","file-opener":r(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.4b35bc77.js.map
