import{b as r,u as n}from"./workspaceStore.66fb9534.js";import{W as c}from"./PlayerConfigProvider.19373623.js";import{d as i,g as d,r as p,u as o,o as u,c as f,w as l,S as _,b as m}from"./index.c4f9f025.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="51245c95-6933-4da2-b99c-0533c73a4ac5",t._sentryDebugIdIdentifier="sentry-dbid-51245c95-6933-4da2-b99c-0533c73a4ac5")}catch{}})();const h=i({__name:"App",setup(t){const a=r(),e=n();return e.actions.fetch(),d(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=p("RouterView");return o(e).state.workspace?(u(),f(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:l(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.4723527c.js.map
