import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.259e7ec5.js";import{L as d}from"./tasksController.c0cc912e.js";import{d as f,e as u,o as _,c as m,w as t,b as s,u as o,dd as y,aG as i,bT as k,dh as b,a0 as w}from"./index.c4f9f025.js";import{C as T}from"./ContentLayout.878e9d53.js";import{a as g}from"./ant-design.b662a793.js";import"./metadata.b87c17bd.js";import"./PhRobot.vue.b193469b.js";import"./PhWebhooksLogo.vue.81b8f671.js";import"./string.45b9e9dc.js";import"./dayjs.a30dbbb3.js";import"./index.6797054a.js";import"./gateway.408bdde1.js";import"./popupNotifcation.ebc30b56.js";import"./linters.cd09d15a.js";import"./asyncComputed.bfad5b5f.js";import"./scripts.5a5dc9ce.js";import"./record.8b302d80.js";import"./polling.19d6afa8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7fece88e-ea28-4ac9-aea9-3c1005c47188",e._sentryDebugIdIdentifier="sentry-dbid-7fece88e-ea28-4ac9-aea9-3c1005c47188")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new d,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(_(),m(T,null,{default:t(()=>[s(o(b),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(k),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.a935d330.js.map
