import{d as t,o as d,Y as o,b as s,u as c,by as r,a0 as _}from"./index.c4f9f025.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f9a2cd61-766a-4492-98cd-a27c7afdaf3b",e._sentryDebugIdIdentifier="sentry-dbid-f9a2cd61-766a-4492-98cd-a27c7afdaf3b")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(d(),o("div",i,[s(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.0b1f3546.js.map
