import{a0 as n,r as t,o as c,c as s}from"./index.c4f9f025.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="d1d98b6c-96d3-4d98-a8e3-0debdac5309f",e._sentryDebugIdIdentifier="sentry-dbid-d1d98b6c-96d3-4d98-a8e3-0debdac5309f")}catch{}})();const r={};function _(e,d){const o=t("RouterView");return c(),s(o,{class:"router"})}const f=n(r,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.b75a7db0.js.map
