import{i as h}from"./metadata.b87c17bd.js";import{W as k}from"./Watermark.b2f20359.js";import{F as w}from"./PhArrowSquareOut.vue.4197b0db.js";import{d as b,eo as v,f as x,e as C,u as e,o as t,Y as m,b as p,w as r,S as D,c as n,aG as f,d9 as y,aS as I,eb as z,dh as _,ec as S,e9 as F,ed as T,a0 as B}from"./index.c4f9f025.js";import{u as H}from"./workspaceStore.66fb9534.js";import"./index.e66c3216.js";import{L}from"./LoadingOutlined.7c61f089.js";import{C as N}from"./Card.b2dea59d.js";import"./PhRobot.vue.b193469b.js";import"./PhWebhooksLogo.vue.81b8f671.js";import"./url.b319ee4d.js";import"./colorHelpers.4725e4d8.js";import"./TabPane.4690ebe8.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="756b6965-d9ae-4381-91e9-e4ca7aa13fa7",o._sentryDebugIdIdentifier="sentry-dbid-756b6965-d9ae-4381-91e9-e4ca7aa13fa7")}catch{}})();const V={key:0,class:"home-container"},W=b({__name:"Home",setup(o){const i=v(),l=H(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(t(),m("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(t(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(t(!0),m(I,{key:1},z(u.value,a=>(t(),n(e(N),{key:a.id,class:T(["form-card",{loading:c.value===a.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(a.path,a.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(t(),n(S(e(h)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(F(a.name),1)]),_:2},1024),c.value!==a.id?(t(),n(e(w),{key:0,size:"20"})):(t(),n(e(L),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(k,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const U=B(W,[["__scopeId","data-v-060376d1"]]);export{U as default};
//# sourceMappingURL=Home.1c342eef.js.map
