import{U as s,dA as i,dB as d}from"./index.c4f9f025.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="aec01ff0-d3f2-4b2a-a1e3-5699f3154ce4",e._sentryDebugIdIdentifier="sentry-dbid-aec01ff0-d3f2-4b2a-a1e3-5699f3154ce4")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(d),y=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{y as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.a30dbbb3.js.map
