[data-v-a66b7046]:root{--main-font-family: DM Sans, sans-serif}[data-v-a66b7046]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-a66b7046]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-a66b7046]{background-color:#fff;padding:10px}.files-navigator[data-v-a66b7046]{display:flex;flex-direction:column;gap:20px}.files-navigator .file-size[data-v-a66b7046]{color:#8692a5}.files-navigator .char-match[data-v-a66b7046]{background-color:#ffee56}.files-navigator[data-v-a66b7046] .ant-tree{height:100%}
