import{R as c,f as a}from"./index.c4f9f025.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="ea3aef85-22fc-4050-a619-3c9aeaef8ad3",r._sentryDebugIdIdentifier="sentry-dbid-ea3aef85-22fc-4050-a619-3c9aeaef8ad3")}catch{}})();const i=r=>{const e=c({loading:!0,result:null,error:null}),l=t=>(e.value={loading:!1,result:t,error:null},t),o=t=>{e.value={loading:!1,result:null,error:t}},n=async()=>(e.value={loading:!0,result:e.value.result,error:null},r().then(l).catch(o));n();const s=a(()=>e.value.loading),u=a(()=>e.value.result),d=a(()=>e.value.error);return{loading:s,result:u,error:d,refetch:n}};export{i as a};
//# sourceMappingURL=asyncComputed.bfad5b5f.js.map
