import{k as i,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as g}from"./index.c4f9f025.js";import{s as b,c as y,a}from"./workspaceStore.66fb9534.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.4723527c.js";import"./url.b319ee4d.js";import"./colorHelpers.4725e4d8.js";import"./PlayerConfigProvider.19373623.js";import"./index.44d5a9ff.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="3a54251d-5987-43f2-a9b4-6fa593a0bd48",t._sentryDebugIdIdentifier="sentry-dbid-3a54251d-5987-43f2-a9b4-6fa593a0bd48")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=i({render:()=>f(l)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.e6054649.js.map
