import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.6793c8ae.js";import{d as f,eo as m,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.c4f9f025.js";import{u as h}from"./workspaceStore.66fb9534.js";import"./Logo.88222daa.js";import"./string.45b9e9dc.js";import"./OTPInput.b5565e2d.js";import"./index.8a59a397.js";import"./url.b319ee4d.js";import"./colorHelpers.4725e4d8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f5401e83-e3df-49bd-9e31-91bb07267548",e._sentryDebugIdIdentifier="sentry-dbid-f5401e83-e3df-49bd-9e31-91bb07267548")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:s,...a}=t.query;if(s){await o.push({path:s,query:a,params:t.params});return}o.push({name:"playerHome",query:a})};return(s,a)=>{var c,d,u,p,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(u=n(r).state.workspace)==null?void 0:u.brandName,locale:(i=(p=n(r).state.workspace)==null?void 0:p.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-cb33c596"]]);export{C as default};
//# sourceMappingURL=Login.04e929a7.js.map
