import{d as f,eo as b,ea as m,o as l,c as p,w as u,u as n,Y as _,eb as g,b as y,a as v,e9 as w,aS as k}from"./index.c4f9f025.js";import{A as I,T}from"./TabPane.4690ebe8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="61f128f1-4fd2-4137-8221-da55aa339ac4",e._sentryDebugIdIdentifier="sentry-dbid-61f128f1-4fd2-4137-8221-da55aa339ac4")}catch{}})();const B=f({__name:"TablesTabs",setup(e){const a=b(),t=m(),c=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(l(),p(n(T),{"active-key":n(c),options:r,"onUpdate:activeKey":i},{default:u(()=>[(l(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:u(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{B as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.6dec6be0.js.map
