import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.259e7ec5.js";import{R as f}from"./tasksController.c0cc912e.js";import{d as _,ea as b,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.c4f9f025.js";import"./gateway.408bdde1.js";import{a as j,B as x}from"./build.4c8cfde3.js";import{a as C}from"./project.993b67c9.js";import"./tables.95f3c281.js";import{a as D}from"./asyncComputed.bfad5b5f.js";import"./metadata.b87c17bd.js";import"./PhRobot.vue.b193469b.js";import"./PhWebhooksLogo.vue.81b8f671.js";import"./ant-design.b662a793.js";import"./string.45b9e9dc.js";import"./dayjs.a30dbbb3.js";import"./index.6797054a.js";import"./linters.cd09d15a.js";import"./scripts.5a5dc9ce.js";import"./record.8b302d80.js";import"./polling.19d6afa8.js";import"./popupNotifcation.ebc30b56.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="996eb49f-25a9-4280-af89-8666ed412e75",e._sentryDebugIdIdentifier="sentry-dbid-996eb49f-25a9-4280-af89-8666ed412e75")}catch{}})();const U=_({__name:"Tasks",setup(e){const a=b().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(c=>c.latest);if(!r)return null;const[u,d]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:d}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.fd40d169.js.map
