.executing-line{background-color:#0000ff1a;border:1px solid blue}.error-line{background-color:#ff00001a;border:1px solid orangered}.source-code-container[data-v-1bedd218]{display:flex;flex-direction:column;gap:10px;height:100%;overflow:hidden;position:relative}.source-code-container .file-input[data-v-1bedd218]{margin-bottom:0;flex-grow:1}.source-code-container .monaco-element[data-v-1bedd218]{height:100%}.source-code-container .monaco-element.hide[data-v-1bedd218]{display:none}.source-code-container .monaco-element.blur[data-v-1bedd218]{filter:blur(8px);pointer-events:none}.source-code-container .code-container[data-v-1bedd218]{width:100%;height:100%;position:relative}.source-code-container .not-found-container[data-v-1bedd218]{position:absolute;z-index:2;width:100%;height:100%;display:flex;justify-content:center;align-items:center}.source-code-container .clickable[data-v-1bedd218]{cursor:pointer;display:flex;align-items:center;gap:8px}
