import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.17cbdacc.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.c4f9f025.js";import"./gateway.408bdde1.js";import"./popupNotifcation.ebc30b56.js";import"./fetch.02ea8ffd.js";import"./record.8b302d80.js";import"./SaveButton.e6b204c5.js";import"./UnsavedChangesHandler.b2721048.js";import"./ExclamationCircleOutlined.d86a7477.js";import"./CrudView.326cc18b.js";import"./router.a2550079.js";import"./Badge.f662d019.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.00c3f4e2.js";import"./BookOutlined.ec23cf35.js";import"./url.b319ee4d.js";import"./PhDotsThreeVertical.vue.d3a732a1.js";import"./index.6797054a.js";import"./index.c251cf6d.js";import"./asyncComputed.bfad5b5f.js";import"./polling.19d6afa8.js";import"./PhPencil.vue.e6ad1f42.js";import"./index.8a59a397.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="f1463730-6c89-43aa-96ca-d7d9eeef1508",o._sentryDebugIdIdentifier="sentry-dbid-f1463730-6c89-43aa-96ca-d7d9eeef1508")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.e11e34e6.js.map
